import time
import logging
import os
import multiprocessing
from logging.handlers import TimedRotatingFileHandler

lock_Rollover = multiprocessing.Lock()


class MultiProcessSafeTimedRotatingFileHandler(TimedRotatingFileHandler):
    def __init__(self, filename, when='h', interval=1, backupCount=0, encoding=None, delay=False, utc=False,
                 atTime=None):
        super().__init__(filename, when, interval, backupCount, encoding, delay, utc, atTime)
        filename = self.baseFilename
        if os.path.exists(filename):
            line = open(filename, "r").readline()
            if line == '':
                t = int(time.time())
            else:
                n = line.find(',')
                line = line[1:n]
                t = int(time.mktime(time.strptime(line, '%Y-%m-%d %H:%M:%S')))
        # t = os.stat(filename)[ST_MTIME]
        else:
            t = int(time.time())
        self.rolloverAt = self.computeRollover(t)

    def emit(self, record):
        """
        Emit a record.
        Output the record to the file, catering for rollover as described
        in doRollover().
        """
        try:
            if self.shouldRollover(record):
                if self.stream:
                    self.stream.close()
                    self.stream = None
                with lock_Rollover:
                    f = open(self.baseFilename, "r")

                    line = f.readline()
                    if line == '':
                        f.close()
                        self.doRollover()
                    else:
                        f.close()

                        n = line.find(',')
                        line = line[1:n]
                        t = int(time.mktime(time.strptime(line, '%Y-%m-%d %H:%M:%S')))

                        # last_time = int(os.stat(self.baseFilename)[ST_MTIME])#last change time
                        now = int(time.time())
                        if t >= self.rolloverAt:
                            if self.computeRollover(t) <= now:
                                self.rolloverAt = self.computeRollover(t)
                                self.doRollover()
                            else:
                                self.rolloverAt = t
                                self.stream = self._open()
                        else:
                            if self.computeRollover(t) >= now:
                                self.rolloverAt = t
                                self.stream = self._open()
                            else:
                                self.doRollover()

            logging.FileHandler.emit(self, record)
        except Exception:
            self.handleError(record)



import os
import json
import threading
import traceback
from functools import wraps
import flask
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker

from winhye_common.winhye_logger import logging as logging

logger = logging.getLogger()

__all__ = ["sess", "get_session", "db_session", "create_session"]

# dict for singleton, database URL as key, db engine as value
db_engines = {}
sess = threading.local()

_lock = threading.RLock()


def _acquire_lock():
    if _lock:
        _lock.acquire()


def _release_lock():
    if _lock:
        _lock.release()


def get_session(url: str, timeout: int = 30, **configs):
    """
    Return session based on database URL, maintain singleton for every URL using a dict.

    :param url: str, database URL, example: "dialect+driver://username:password@host:port/database"
    :param timeout: int, session timeout, default is 30(s)
    :param configs: other configs
    :return: sqlalchemy Session
    """
    _acquire_lock()
    if url in db_engines:
        engine = db_engines[url]
    else:
        logger.debug("DB_SESSION CONFIGS[{}]".format(configs))
        engine = create_engine(url, pool_size=10, max_overflow=10, echo=True, pool_timeout=timeout, **configs)
        db_engines[url] = engine
    _release_lock()
    session = sessionmaker(bind=engine)
    return session()


def create_session(url: str, timeout: int = 30):
    """
    Return session based on database URL in thread-local

    :param url: str, database URL, example: "dialect+driver://username:password@host:port/database"
    :param timeout: int, default is 30(s)
    :return: sqlalchemy Session
    """
    return get_session(url, timeout)


def db_session(pg_config: dict = None, mysql_config: dict = None, timeout: int = 30, auto_commit: bool = True):
    """
    Used as decorator, maintaining a sqlalchemy session during the scope. (reserved function root_path for Swagger)
    usage example: @db_session(pg_config=<postgresql config>, mysql_config=<mysql config>)
    P.S. only for Flask framework!

    :param pg_config: dict, postgresql config
    :param mysql_config: dict, mysql config
    :param timeout: int, default is 30(s)
    :param auto_commit: bool, default is True
    :return: decorated function
    """

    def decorator(func):
        func.root_path = os.path.dirname(os.path.abspath(func.__globals__["__file__"]))

        @wraps(func)
        def wrapper(*args, **kwargs):
            sess.pg_sess = None
            sess.mysql_sess = None
            if pg_config is not None:
                pg_url = "postgresql+psycopg2://{0}:{1}@{2}:{3}/{4}".format(
                    pg_config["db_user"], pg_config["db_passwd"],
                    pg_config["db_host"], pg_config["db_port"],
                    pg_config["db_name"]
                )
                logger.debug(pg_url)
                sess.pg_sess = get_session(pg_url, timeout)
                logger.debug("DB_SESSION GET_PG_SESS[{}]".format(sess.pg_sess))
            if mysql_config is not None:
                mysql_url = "mysql+mysqldb://{0}:{1}@{2}:{3}/{4}".format(
                    mysql_config["db_user"], mysql_config["db_passwd"],
                    mysql_config["db_host"], mysql_config["db_port"],
                    mysql_config["db_name"]
                )
                if "pool_recycle" in mysql_config:
                    sess.mysql_sess = get_session(mysql_url, timeout, pool_recycle=int(mysql_config["pool_recycle"]))
                else:
                    sess.mysql_sess = get_session(mysql_url, timeout)
                logger.debug("DB_SESSION GET_MYSQL_SESS[{}]".format(sess.mysql_sess))
            try:
                ret = func(*args, **kwargs)
                if auto_commit is False:
                    logger.debug("auto_commit is False, DB_SESSION directly close...")
                    if sess.pg_sess is not None:
                        logger.debug("DB_SESSION PG_SESS[{}]".format(sess.pg_sess))
                        sess.pg_sess.close()
                    if sess.mysql_sess is not None:
                        logger.debug("DB_SESSION MYSQL_SESS[{}]".format(sess.mysql_sess))
                        sess.mysql_sess.close()
                    return ret
                else:
                    # supported response type: int, dict, flask.Response, tuple[0] in (int, dict, flask.Response)
                    if type(ret) is int:
                        code = ret
                    elif type(ret) is dict:
                        code = ret.get("code")
                    elif type(ret) is flask.Response:
                        code = ret.json.get("code")
                    elif type(ret) is tuple and type(ret[0]) is int:
                        code = ret[0]
                    elif type(ret) is tuple and type(ret[0]) is dict:
                        code = ret[0].get("code")
                    elif type(ret) is tuple and type(ret[0]) is flask.Response:
                        code = ret[0].json.get("code")
                    else:
                        raise Exception("unsupported return type for @db_session: {0}".format(type(ret)))

                    try:
                        if code in [0, 200, 903, 909]:
                            logger.info("DB_SESSION commit due to zero code")
                            if sess.pg_sess is not None:
                                logger.debug("DB_SESSION PG_SESS[{}]".format(sess.pg_sess))
                                sess.pg_sess.commit()
                            if sess.mysql_sess is not None:
                                logger.debug("DB_SESSION MYSQL_SESS[{}]".format(sess.mysql_sess))
                                sess.mysql_sess.commit()
                        else:
                            logger.info("DB_SESSION rollback due to non-zero code...")
                            if sess.pg_sess is not None:
                                logger.debug("DB_SESSION PG_SESS[{}]".format(sess.pg_sess))
                                sess.pg_sess.rollback()
                            if sess.mysql_sess is not None:
                                logger.debug("DB_SESSION MYSQL_SESS[{}]".format(sess.mysql_sess))
                                sess.mysql_sess.rollback()
                    except Exception:
                        error_message = "error occurs when {operation} database".format(
                            operation="commit" if code == 0 else "rollback")
                        logger.error(error_message)
                        if sess.pg_sess is not None:
                            logger.debug("DB_SESSION PG_SESS[{}]".format(sess.pg_sess))
                            sess.pg_sess.close()
                        if sess.mysql_sess is not None:
                            logger.debug("DB_SESSION MYSQL_SESS[{}]".format(sess.mysql_sess))
                            sess.mysql_sess.close()
                        return flask.Response(status=500, response=json.dumps({"message": error_message}))

                    logger.debug("database operations finished, DB_SESSION close...")
                    if sess.pg_sess is not None:
                        logger.debug("DB_SESSION PG_SESS[{}]".format(sess.pg_sess))
                        sess.pg_sess.close()
                    if sess.mysql_sess is not None:
                        logger.debug("DB_SESSION MYSQL_SESS[{}]".format(sess.mysql_sess))
                        sess.mysql_sess.close()
                    return ret

            except Exception as e:
                logger.error(e)
                logger.debug(traceback.format_exc())

                if auto_commit is True:
                    logger.debug("session rollback due to exception")
                    try:
                        if sess.pg_sess is not None:
                            logger.debug("DB_SESSION PG_SESS[{}]".format(sess.pg_sess))
                            sess.pg_sess.rollback()
                        if sess.mysql_sess is not None:
                            logger.debug("DB_SESSION MYSQL_SESS[{}]".format(sess.mysql_sess))
                            sess.mysql_sess.rollback()
                    except:
                        error_message = "error occurs when rollback database"
                        logger.error(error_message)
                        if sess.pg_sess is not None:
                            logger.debug("DB_SESSION PG_SESS[{}]".format(sess.pg_sess))
                            sess.pg_sess.close()
                        if sess.mysql_sess is not None:
                            logger.debug("DB_SESSION MYSQL_SESS[{}]".format(sess.mysql_sess))
                            sess.mysql_sess.close()
                        return flask.Response(status=500, response=json.dumps({"message": error_message}))

                if sess.pg_sess is not None:
                    logger.debug("DB_SESSION PG_SESS[{}]".format(sess.pg_sess))
                    sess.pg_sess.close()
                if sess.mysql_sess is not None:
                    logger.debug("DB_SESSION MYSQL_SESS[{}]".format(sess.mysql_sess))
                    sess.mysql_sess.close()
                return flask.Response(status=500)

        return wrapper

    return decorator



from elasticsearch import Elasticsearch
import datetime


class elasticSearch():
    #  index_type 储存的是什么类型：server & mqtt   index_name 储存那个空间
    def __init__(self, index_type: str, index_name: str, ip="127.0.0.1"):

        # self.es = Elasticsearch([ip], http_auth=('elastic', 'password'), port=9200)
        self.es = Elasticsearch("121.40.111.33:39011")  # todo 后续改到配置中心或者当作参数传入
        self.index_type = index_type
        self.index_name = index_name
        if not self.es.indices.exists(index=index_name):
            self.create_index()

    # 创建 index_name 为某某的储存空间
    def create_index(self):
        if self.es.indices.exists(index=self.index_name) is True:
            self.es.indices.delete(index=self.index_name)
        self.es.indices.create(index=self.index_name, ignore=400)

    # 删除 index_name 为某某的储存空间
    def delete_index(self):
        try:
            self.es.indices.delete(index=self.index_name)
        except:
            pass

    def get_doc(self, uid):
        return self.es.get(index=self.index_name, id=uid)

    # 插入一条
    def insert_one(self, doc: dict):
        return self.es.index(index=self.index_name, doc_type=self.index_type, body=doc)

    # 插入多条
    def insert_array(self, docs: list):
        for doc in docs:
            self.es.index(index=self.index_name, doc_type=self.index_type, body=doc)

    # query 查询value为url  page_size一页多少条 page_no为从多少条数据开始
    def search(self, query: str = '', page_size: int = 10, page_no: int = 0):
        dsl = {
            "query": {
                "multi_match": {
                    "query": query,
                    "fields": ["url"]
                }
            },
            "highlight": {
                "fields": {
                    "url": {}
                }
            }
        }
        if query:
            match_data = self.es.search(index=self.index_name, body=dsl, size=page_size, from_=page_no)
        else:
            match_data = self.es.search(index=self.index_name, body='', size=page_size, from_=page_no)
        return match_data

# es = elasticSearch(index_type="server_log", index_name="iot-server")
# es.create_index()
# for i in range(10):
#     vv = 'ceshi' + str(i)
#     data = {
#         'url': vv,
#         'content': "select %s from user_info" % vv,
#         'create_time': datetime.datetime.now()
#     }
#
#     es.insert_one(doc=data)

#  查询
# es = elasticSearch(index_type="server_log", index_name="iot-server")
# es.search('iot-server')
# print('')



import os
import re
import datetime
import logging

try:
    import codecs
except ImportError:
    codecs = None


class MultiprocessHandler(logging.FileHandler):
    def __init__(self, filename, when='D', backupCount=0, encoding=None, delay=False):
        self.prefix = filename
        self.backupCount = backupCount
        self.when = when.upper()
        self.extMath = r"(\d{4}-\d{1,2}-\d{1,2})"
        self.when_dict = {
            'S': "%Y-%m-%d_%H-%M-%S",
            'M': "%Y-%m-%d_%H-%M",
            'H': "%Y-%m-%d_%H",
            'D': "%Y-%m-%d"
        }
        self.suffix = self.when_dict.get(when)
        if not self.suffix:
            raise ValueError(u"指定的日期间隔单位无效: %s" % self.when)
        self.filefmt = os.path.join("logs", "%s.%s" % (self.prefix, self.suffix))
        self.filePath = datetime.datetime.now().strftime(self.filefmt)
        _dir = os.path.dirname(self.filefmt)
        try:
            if not os.path.exists(_dir):
                os.makedirs(_dir)
        except Exception:
            print(u"创建文件夹失败")
            print(u"文件夹路径：" + self.filePath)
            pass

        if codecs is None:
            encoding = None

        logging.FileHandler.__init__(self, self.filePath, 'a+', encoding, delay)

    def shouldChangeFileToWrite(self):
        """更改日志写入目的写入文件
        :return True 表示已更改，False 表示未更改"""
        # 以当前时间获得新日志文件路径
        _filePath = datetime.datetime.now().strftime(self.filefmt)
        # 新日志文件日期 不等于 旧日志文件日期，则表示 已经到了日志切分的时候
        #   更换日志写入目的为新日志文件。
        # 例如 按 天 （D）来切分日志
        #   当前新日志日期等于旧日志日期，则表示在同一天内，还不到日志切分的时候
        #   当前新日志日期不等于旧日志日期，则表示不在
        # 同一天内，进行日志切分，将日志内容写入新日志内。
        if _filePath != self.filePath:
            self.filePath = _filePath
            return True
        return False

    def doChangeFile(self):
        """输出信息到日志文件，并删除多于保留个数的所有日志文件"""
        # 日志文件的绝对路径
        self.baseFilename = os.path.abspath(self.filePath)
        # stream == OutStream
        # stream is not None 表示 OutStream中还有未输出完的缓存数据
        if self.stream:
            # flush close 都会刷新缓冲区，flush不会关闭stream，close则关闭stream
            # self.stream.flush()
            self.stream.close()
            # 关闭stream后必须重新设置stream为None，否则会造成对已关闭文件进行IO操作。
            self.stream = None
        # delay 为False 表示 不OutStream不缓存数据 直接输出
        #   所有，只需要关闭OutStream即可
        if not self.delay:
            # 这个地方如果关闭colse那么就会造成进程往已关闭的文件中写数据，从而造成IO错误
            # delay == False 表示的就是 不缓存直接写入磁盘
            # 我们需要重新在打开一次stream
            # self.stream.close()
            self.stream = self._open()
        # 删除多于保留个数的所有日志文件
        if self.backupCount > 0:
            for s in self.getFilesToDelete():
                os.remove(s)

    def getFilesToDelete(self):
        # 筛选文件-->文件排序-->删除日志
        dirName, _ = os.path.split(self.baseFilename)
        fileNames = os.listdir(dirName)
        result = []
        prefix = self.prefix + '.'
        plen = len(prefix)
        for fileName in fileNames:
            # 匹配前缀
            if fileName[:plen][:fileName[:plen].rfind('.')] in prefix:
                # 匹配日期
                if re.search(self.extMath, fileName[:plen]):
                    print(os.path.join(dirName, fileName))
                    result.append(os.path.join(dirName, fileName))
        if len(result) < self.backupCount:
            result = []
        else:
            result = result[:len(result) - self.backupCount]
        return result

    def emit(self, record):
        """发送一个日志记录
        覆盖FileHandler中的emit方法，logging会自动调用此方法"""
        try:
            if self.shouldChangeFileToWrite():
                self.doChangeFile()
            logging.FileHandler.emit(self, record)
        except (KeyboardInterrupt, SystemExit):
            raise
        except:
            self.handleError(record)



import json
import os
import time
import hmac
import hashlib
import base64
import urllib.parse
import requests

from ..config.config_client import ConfigClient

LIB_APP_ID = "winhye_common"
app_id = os.environ.get("APP_ID", "NOT_EXIST")
if app_id == "NOT_EXIST":
    app_id = LIB_APP_ID
ConfigClient.init(app_id)


class DingAlarm:
    def __init__(self):
        alarm_conf = ConfigClient.get_configger("winhye_software.common")
        alarm_config = alarm_conf.get_group("alarm")
        self.secret = alarm_config.secret
        self.url = alarm_config.url
        self.atMobiles = json.loads(alarm_config.atMobiles)
        self.isAtAll = eval(alarm_config.isAtAll)

    def get_sign(self):
        timestamp = str(round(time.time() * 1000))
        secret_enc = self.secret.encode('utf-8')
        string_to_sign = '{}\n{}'.format(timestamp, self.secret)
        string_to_sign_enc = string_to_sign.encode('utf-8')
        hmac_code = hmac.new(secret_enc, string_to_sign_enc, digestmod=hashlib.sha256).digest()
        sign = urllib.parse.quote_plus(base64.b64encode(hmac_code))
        return timestamp, sign

    def send_alarm_message(self, msg):
        timestamp, sign = self.get_sign()
        url = f"{self.url}&timestamp={timestamp}&sign={sign}"
        env = os.environ.get("ENV", "NOT_ENV")
        idc = os.environ.get("IDC", "NOT_IDC")
        message = {
            "msgtype": "text",
            "text": {
                "content": f"{app_id}-{env}-{idc}:\n{msg}"
            },
            "at": {  # @的人
                "atMobiles": self.atMobiles,  # 钉钉的电话号码
                "atUserIds": [],
                "isAtAll": self.isAtAll
            }
        }
        requests.post(url, json=message)


ding_alarm = DingAlarm()



import os
import base64

from Crypto import Random
from Crypto.PublicKey import RSA
from Crypto.Cipher import PKCS1_v1_5

from ..config.config_client import ConfigClient


__all__ = ["CookieRsa"]


class CookieRsa:
    def __init__(self):
        app_id = os.environ.get("APP_ID", "NOT_EXIST")
        if app_id == "NOT_EXIST":
            app_id = "winhye_common"
        ConfigClient.init(app_id)
        ras_conf = ConfigClient.get_configger("winhye_software.common")
        self.ras_config = ras_conf.get_group("ras")

    # 初始化公钥私钥
    @staticmethod
    def __init_key():
        key_dir = "/data/log/rsa_key"
        if not os.path.exists(key_dir):
            os.makedirs(key_dir)

        # 初始化RSA对象， 伪随机数生成器
        rsa = RSA.generate(1024, Random.new().read)

        # 私钥
        private_key = rsa.exportKey()
        private_key_path = os.path.join(key_dir, "private_key.pem")

        # 公钥
        public_key = rsa.publickey().exportKey()
        public_key_path = os.path.join(key_dir, "public_key.pem")

        with open(private_key_path, 'w') as f:
            f.write(private_key.decode())

        with open(public_key_path, 'w') as f:
            f.write(public_key.decode())

        return private_key, public_key

    # 获取私钥
    def __get_private_key(self):
        return self.ras_config.private_key

    # 获取公钥
    def __get_public_key(self):
        return self.ras_config.public_key

    # 加密
    def rsa_encrypt(self, content: str) -> str:
        public = RSA.importKey(self.__get_public_key())
        cipher = PKCS1_v1_5.new(public)
        return base64.b64encode(cipher.encrypt(content.encode('utf-8'))).decode('utf-8')

    # 解密
    def rsa_decrypt(self, content: str) -> str:
        private = RSA.importKey(self.__get_private_key())
        cipher = PKCS1_v1_5.new(private)
        return cipher.decrypt(base64.b64decode(content), b'error: decrypt fail').decode('utf-8')



from .apollo_client import ApolloClient


class ConfigGroup(object):
    """
    Config group, supporting <group>.<item> operation to get value conveniently

    :param client: ApolloClient, pyapollo client
    :param namespace: str, config namespace
    :param group: str, config common prefix
    """
    def __init__(self, client: ApolloClient, namespace: str, group: str):
        self._client = client
        self._namespace = namespace
        self._group = group

    def __getattr__(self, item):
        return self._client.get_value("{group}.{item}".format(group=self._group, item=item), namespace=self._namespace)

    def to_connection_string(self, dialect: str) -> str:
        """
        Convert config_group to connection string for database configs

        :param dialect: str, identifying name of the dialect, such as sqlite, mysql, postgresql, oracle, or mssql.
        :return:
        """
        driver = "mysqldb" if dialect == "mysql" else "psycopg2"
        try:
            return "{dialect}+{driver}://{user}:{password}@{host}:{port}/{db_name}".format(
                dialect=dialect, driver=driver,
                user=self._client.get_value("{group}.db_user".format(group=self._group), namespace=self._namespace),
                password=self._client.get_value("{group}.db_passwd".format(group=self._group), namespace=self._namespace),
                host=self._client.get_value("{group}.db_host".format(group=self._group), namespace=self._namespace),
                port=self._client.get_value("{group}.db_port".format(group=self._group), namespace=self._namespace),
                db_name=self._client.get_value("{group}.db_name".format(group=self._group), namespace=self._namespace)
            )
        except:
            return ""



config_json = {
    "online": {
        "log_level": {
            "console": "ERROR",
            "file": "DEBUG",
            "third_log": True
        },
        "alarm": {
            "secret": "SEC0bb5fc4f03725bdb95b7647f22cffae20883c155354545cbcc9a283badd7b5a6",
            "url": "https://oapi.dingtalk.com/robot/send?access_token=23d1a07564a391d2d9041954bdaa1db0a3c3b231366ac314d6bd289ec0dc9e4f",
            "atMobiles": [],
            "isAtAll": True
        }
    },
    "pre": {
        "log_level": {
            "console": "ERROR",
            "file": "DEBUG",
            "third_log": True
        },
        "alarm": {
            "secret": "SECdbd47e3cfb9229e69dc6ea98ae35c6e4220c8e6da50c3d7fbbcdecc12445c187",
            "url": "https://oapi.dingtalk.com/robot/send?access_token=2978d209d8667f1bfc57d985b00b7366a6d3bcbd762f2d5f128a14350e263e87",
            "atMobiles": [],
            "isAtAll": False
        }
    },
    "kaifa": {
        "log_level": {
            "console": "DEBUG",
            "file": "DEBUG",
            "third_log": True  # True 不打印
        },
        "alarm": {
            "secret": "SEC2e957a153c19f536496057f09d4e17da533d86ebb5308faf01d6ff29745aaeac",
            "url": "https://oapi.dingtalk.com/robot/send?access_token=35a35b15e741c55563c627720bc829a6aab341806d56510c8036c99f282c8694",
            "atMobiles": [],
            "isAtAll": False
        }
    }
}



# -*- coding: utf-8 -*-
from alibabacloud_dysmsapi20170525.client import Client as Dysmsapi20170525Client
from alibabacloud_tea_openapi import models as open_api_models
from alibabacloud_dysmsapi20170525 import models as dysmsapi_20170525_models


class Sample:
    def __init__(self, access_key_id, access_key_secret):
        self.access_key_secret = access_key_secret
        self.access_key_id = access_key_id

    @staticmethod
    def create_client(access_key_id: str, access_key_secret: str, ) -> Dysmsapi20170525Client:
        """
        使用AK&SK初始化账号Client
        @param access_key_id:
        @param access_key_secret:
        @return: Client
        @throws Exception
        """
        config = open_api_models.Config(
            # 您的AccessKey ID,
            access_key_id=access_key_id,
            # 您的AccessKey Secret,
            access_key_secret=access_key_secret
        )
        # 访问的域名
        config.endpoint = 'dysmsapi.aliyuncs.com'
        return Dysmsapi20170525Client(config)

    # 同步发送
    def send_sms(self, phone_numbers, sign_name, template_code, template_param):
        """
        :param phone_numbers:要发送的手机号
        :param sign_name:短信签名名称
        :param template_code:短信模板ID
        :param template_param:短信模板变量对应的实际值
        :return:
        """
        client = Sample.create_client(self.access_key_id, self.access_key_secret)
        # 分别为 AccessKey ID AccessKey Secret
        send_sms_request = dysmsapi_20170525_models.SendSmsRequest(
            phone_numbers=phone_numbers,  # 要发送的手机号  必填
            sign_name=sign_name,  # 短信签名名称  必填
            template_code=template_code,  # 短信模板ID  必填
            template_param=template_param,  # 短信模板变量对应的实际值
            # sms_up_extend_code='',  # 上行短信扩展码
            # out_id=''  # 外部流水扩展字段
        )
        # 复制代码运行请自行打印 API 的返回值
        return client.send_sms(send_sms_request)



# -*- coding: utf-8 -*-
import json
import logging
import sys
import threading
import time

import requests


class ApolloClient(object):
    def __init__(self, app_id, cluster='default', config_server_url='http://localhost:8080', timeout=35, ip=None):
        self.config_server_url = config_server_url
        self.appId = app_id
        self.cluster = cluster
        self.timeout = timeout
        self.stopped = False
        self.init_ip(ip)

        self._stopping = False
        self._cache = {}
        self._notification_map = {'application': -1}

    def init_ip(self, ip):
        if ip:
            self.ip = ip
        else:
            import socket
            try:
                s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
                s.connect(('8.8.8.8', 53))
                ip = s.getsockname()[0]
            finally:
                s.close()
            self.ip = ip

    # Main method
    def get_value(self, key, default_val=None, namespace='application', auto_fetch_on_cache_miss=False):
        if namespace not in self._notification_map:
            self._notification_map[namespace] = -1
            logging.getLogger(__name__).info("Add namespace '%s' to local notification map", namespace)

        if namespace not in self._cache:
            self._cache[namespace] = {}
            logging.getLogger(__name__).info("Add namespace '%s' to local cache", namespace)
            # This is a new namespace, need to do a blocking fetch to populate the local cache
            self._long_poll()

        if key in self._cache[namespace]:
            return self._cache[namespace][key]
        else:
            if auto_fetch_on_cache_miss:
                return self._cached_http_get(key, default_val, namespace)
            else:
                return default_val

    # Start the long polling loop. Two modes are provided:
    # 1: thread mode (default), create a worker thread to do the loop. Call self.stop() to quit the loop
    # 2: eventlet mode (recommended), no need to call the .stop() since it is async
    def start(self, use_eventlet=False, eventlet_monkey_patch=False, catch_signals=True):
        # First do a blocking long poll to populate the local cache, otherwise we may get racing problems
        if len(self._cache) == 0:
            self._long_poll()
        if use_eventlet:
            import eventlet
            if eventlet_monkey_patch:
                eventlet.monkey_patch()
            eventlet.spawn(self._listener)
        else:
            if catch_signals:
                import signal
                signal.signal(signal.SIGINT, self._signal_handler)
                signal.signal(signal.SIGTERM, self._signal_handler)
                signal.signal(signal.SIGABRT, self._signal_handler)
            t = threading.Thread(target=self._listener)
            t.setDaemon(True)
            t.start()

    def stop(self):
        self._stopping = True
        logging.getLogger(__name__).info("Stopping listener...")

    def _cached_http_get(self, key, default_val, namespace='application'):
        url = '{}/configfiles/json/{}/{}/{}?ip={}'.format(self.config_server_url, self.appId, self.cluster, namespace, self.ip)
        r = requests.get(url)
        if r.ok:
            data = r.json()
            self._cache[namespace] = data
            logging.getLogger(__name__).info('Updated local cache for namespace %s', namespace)
        else:
            data = self._cache[namespace]

        if key in data:
            return data[key]
        else:
            return default_val

    def _uncached_http_get(self, namespace='application'):
        url = '{}/configs/{}/{}/{}?ip={}'.format(self.config_server_url, self.appId, self.cluster, namespace, self.ip)
        r = requests.get(url)
        if r.status_code == 200:
            data = r.json()
            self._cache[namespace] = data['configurations']
            logging.getLogger(__name__).info('Updated local cache for namespace %s release key %s: %s',
                                             namespace, data['releaseKey'],
                                             repr(self._cache[namespace]))

    def _signal_handler(self, signal, frame):
        logging.getLogger(__name__).info('You pressed Ctrl+C!')
        self._stopping = True

    def _long_poll(self):
        url = '{}/notifications/v2'.format(self.config_server_url)
        notifications = []
        for key in self._notification_map:
            notification_id = self._notification_map[key]
            notifications.append({
                'namespaceName': key,
                'notificationId': notification_id
            })

        r = requests.get(url=url, params={
            'appId': self.appId,
            'cluster': self.cluster,
            'notifications': json.dumps(notifications, ensure_ascii=False)
        }, timeout=self.timeout)

        logging.getLogger(__name__).debug('Long polling returns %d: url=%s', r.status_code, r.request.url)

        if r.status_code == 304:
            # no change, loop
            logging.getLogger(__name__).debug('No change, loop...')
            return

        if r.status_code == 200:
            data = r.json()
            for entry in data:
                ns = entry['namespaceName']
                nid = entry['notificationId']
                logging.getLogger(__name__).info("%s has changes: notificationId=%d", ns, nid)
                self._uncached_http_get(ns)
                self._notification_map[ns] = nid
        else:
            logging.getLogger(__name__).warn('Sleep...')
            time.sleep(self.timeout)

    def _listener(self):
        logging.getLogger(__name__).info('Entering listener loop...')
        while not self._stopping:
            self._long_poll()

        logging.getLogger(__name__).info("Listener stopped!")
        self.stopped = True


from .config_group import ConfigGroup


class Configger(object):
    """
    Wrapped ApolloClient with specific namespace

    :param client: ApolloClient, pyapollo client
    :param namespace: str, config namespace
    """
    def __init__(self, client, namespace):
        self.client = client
        self.namespace = namespace

    def get_value(self, key):
        """
        Get value from Apollo by key

        :param key: str, config key
        :return: str, config value
        """
        return self.client.get_value(key, namespace=self.namespace)

    def get_group(self, group):
        """
        Get ConfigGroup by prefix and namespace

        :param group: str, config common prefix
        :return: ConfigGroup
        """
        return ConfigGroup(self.client, self.namespace, group)



import os
import sys
import threading
import time
from multiprocessing import Process, Value, Array

PATH = os.path.abspath(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
sys.path.append(PATH)
print(PATH)

from src.winhye_common.mqtt.mqtt_base import MqttClint, MqttSendMessageException


def mqtt_test(index):
    mqtt_config = {
        "broker": "mqtt-cn-i7m2ceaxt07.mqtt.aliyuncs.com",
        "port": 1883,
        "topic": "reported_kaifa/AGV-S/#",
        "AccessKey_ID": "LTAI5tFbpMr1R4CVCbUePMWy",
        "AccessKey_Secret": "MJ2WWUbIKDg4UY5EbEsgQ983Lkfwff",
        "instance_id": "mqtt-cn-i7m2ceaxt07",
        "group_id": "GID_kaifa"
    }
    data = {
        "type": 1,
        "code": 200,
        "payload": {
            "id": "E41203294",
            "armed": "arm"
        }
    }
    handler = MqttClint(mqtt_config, thread=True)
    # t1 = threading.Thread(target=handler.client.loop_forever)
    # t1.setDaemon(True)
    # t1.start()
    # time.sleep(20)

    try:
        while True:
            handler.send_message("send_kaifa/AGV-S/aa", data)
            # print(index, handler.client_id, handler)
            time.sleep(2)
    except MqttSendMessageException:
        print(111111111111111111)


if __name__ == '__main__':
    # mqtt_test(1)
    p = Process(target=mqtt_test, args=(1,))
    p2 = Process(target=mqtt_test, args=(2,))
    print('Child process will start.')
    p.start()
    p2.start()
    p.join()
    p2.join()
    print("end")





import asyncio
from datetime import datetime

from winhye_common.utils.sms import Sample


def test_oss_a(phone_numbers, sign_name, template_code, template_param):
    # 再发送
    a = datetime.now()
    Sample.send_sms(phone_numbers, sign_name, template_code, template_param)
    b = datetime.now()
    print(b - a)


if __name__ == '__main__':
    # loop = asyncio.get_event_loop()
    test_oss_a(
        '17737263251',
        "北京云汉通航科技有限公司",
        "SMS_223060267",
        '{"code":"66"}'
    )
    # asyncio.run(main('17737263251',
    #                  "北京云汉通航科技有限公司",
    #                  "SMS_223060267",
    #                  '{"code":"55"}'))



import os
import time
from logging.handlers import TimedRotatingFileHandler


class CommonTimedRotatingFileHandler(TimedRotatingFileHandler):

    @property
    def dfn(self):
        currentTime = int(time.time())
        # get the time that this sequence started at and make it a TimeTuple
        dstNow = time.localtime(currentTime)[-1]
        t = self.rolloverAt - self.interval
        if self.utc:
            timeTuple = time.gmtime(t)
        else:
            timeTuple = time.localtime(t)
            dstThen = timeTuple[-1]
            if dstNow != dstThen:
                if dstNow:
                    addend = 3600
                else:
                    addend = -3600
                timeTuple = time.localtime(t + addend)
        dfn = self.rotation_filename(self.baseFilename + "." + time.strftime(self.suffix, timeTuple))

        return dfn

    def shouldRollover(self, record):
        """
        是否应该执行日志滚动操作：
        1、存档文件已存在时，执行滚动操作
        2、当前时间 >= 滚动时间点时，执行滚动操作
        """
        dfn = self.dfn
        t = int(time.time())
        if t >= self.rolloverAt or os.path.exists(dfn):
            return 1
        return 0

    def doRollover(self):
        """
        执行滚动操作
        1、文件句柄更新
        2、存在文件处理
        3、备份数处理
        4、下次滚动时间点更新
        """
        if self.stream:
            self.stream.close()
            self.stream = None
        # get the time that this sequence started at and make it a TimeTuple

        dfn = self.dfn

        # 存档log 已存在处理
        if not os.path.exists(dfn):
            self.rotate(self.baseFilename, dfn)

        # 备份数控制
        if self.backupCount > 0:
            for s in self.getFilesToDelete():
                os.remove(s)

        # 延迟处理
        if not self.delay:
            self.stream = self._open()

        # 更新滚动时间点
        currentTime = int(time.time())
        newRolloverAt = self.computeRollover(currentTime)
        while newRolloverAt <= currentTime:
            newRolloverAt = newRolloverAt + self.interval

        # If DST changes and midnight or weekly rollover, adjust for this.
        if (self.when == 'MIDNIGHT' or self.when.startswith('W')) and not self.utc:
            dstAtRollover = time.localtime(newRolloverAt)[-1]
            dstNow = time.localtime(currentTime)[-1]
            if dstNow != dstAtRollover:
                if not dstNow:  # DST kicks in before next rollover, so we need to deduct an hour
                    addend = -3600
                else:  # DST bows out before next rollover, so we need to add an hour
                    addend = 3600
                newRolloverAt += addend
        self.rolloverAt = newRolloverAt



import os
import sys
import time

PATH = os.path.join(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)))
sys.path.append(PATH)
print(PATH)

from src.winhye_common.config.config_client import ConfigClient


def test_apollo():
    clint = ConfigClient()
    clint.init(lib_app_id='winhye_common')
    alarm = clint.get_group('alarm', "winhye_software.common")
    while True:
        print(alarm.url)
        print(alarm.isAtAll, eval(alarm.isAtAll))
        # print(clint.get_value("alarm.isAtAll", "winhye_software.common"))
        time.sleep(5)


if __name__ == '__main__':
    test_apollo()



import base64
import hmac
import json
import os
import threading
import time
import uuid
from hashlib import sha1

from paho.mqtt import client as mqtt

from winhye_common.utils.exception_base import WinhyeException, ExceptionCode
from winhye_common.winhye_logger import logging as logging

__all__ = ['MqttClint', 'MqttException', 'MqttSendMessageException']
logger = logging.getLogger()


class MqttException(WinhyeException):
    """mqtt exception
    """

    def __init__(self, message: str):
        super(MqttException, self).__init__(ExceptionCode.mqtt, message)


class MqttSendMessageException(WinhyeException):
    """Used only when mqtt message sending fails
    """

    def __init__(self, message: str):
        super(MqttSendMessageException, self).__init__(ExceptionCode.mqtt, message)


class MqttClint:
    _instance = None
    lock = threading.Lock()

    def __new__(cls, *args, **kwargs):
        """
        设置为单例以保证线程中client一致安全
        :param args:
        :param kwargs:
        """
        if cls._instance:

            return cls._instance
        else:
            with cls.lock:
                cls._instance = super().__new__(cls)
                return cls._instance

    def __init__(self, mqtt_config: dict, thread=False):
        """
        topic 在start之前确定就可用
        :param mqtt_config: {
            "AccessKey_ID": 账号AccessKey 从阿里云账号控制台获取
            "AccessKey_Secret": 账号secretKey 从阿里云账号控制台获取
            "instance_id": 实例 ID，购买后从产品控制台获取
            "group_id": MQTT GroupID,创建实例后从 MQTT 控制台创建
            "broker": url地址
            "port": 端口
        }
        :param thread: 是否为多线程运行，默认False
        """
        access_key = mqtt_config["AccessKey_ID"]
        secret_key = mqtt_config["AccessKey_Secret"]
        instance_id = mqtt_config["instance_id"]
        group_id = mqtt_config["group_id"]
        # client_id不能重复，使用自定义字符串 app_id-env-idc-pid(进程id)
        app_id = os.environ.get("APP_ID", str(uuid.uuid1())[:10])
        env = os.environ.get("ENV", str(uuid.uuid1())[:10])
        idc = os.environ.get("IDC", str(uuid.uuid1())[:10])
        pid = os.getpid()
        self.client_id = f"{group_id}@@@{app_id}-{env}-{idc}-{pid}"
        if thread:
            self.client_id += f"-{threading.currentThread().ident}"
        username = 'Signature' + '|' + access_key + '|' + instance_id
        password = base64.b64encode(hmac.new(secret_key.encode(), self.client_id.encode(), sha1).digest()).decode()

        self.broker = mqtt_config["broker"]
        self.port = mqtt_config["port"]
        self.topic = mqtt_config.get("topic", "")

        self.init_config()

        self.client = mqtt.Client(self.client_id, protocol=mqtt.MQTTv311, clean_session=True)
        self.client.username_pw_set(username, password)
        self.client.connect(self.broker, self.port, 60)

    def init_config(self):
        pass

    def init_same_attr(self, *args, **kwargs):
        pass

    def on_connect(self, client, userdata, flags, rc):
        logger.info("Connected with result code " + str(rc))  # 打印连接状态
        client.subscribe(self.topic)

    def on_message(self, client, userdata, msg):
        """
        回调函数。能取到消息值的位置
        :param client:
        :param userdata:
        :param msg:
        :return:
        """
        logger.info(msg.topic + " " + ":" + str(msg.payload))  # 打印接受的消息

    def on_subscribe(self, client, userdata, mid, granted_qos):
        logger.info("On Subscribed: qos = %d" % granted_qos)

    def on_disconnect(self, client, userdata, rc):
        if rc != 0:
            logger.info("Unexpected disconnection %s" % rc)

    def start(self):
        self.client.on_connect = self.on_connect
        self.client.on_message = self.on_message
        self.client.on_subscribe = self.on_subscribe
        self.client.on_disconnect = self.on_disconnect
        self.client.loop_forever()

    def send_message(self, topic: str, data: dict):
        """
        发送消息
        :param topic:  主题
        :param data:  参数
        :return:
        """
        data = json.dumps(data)
        logger.debug(f"topic: {topic}, mqtt_data: {data}")
        rc = self.client.publish(topic, payload=data, qos=0)  # 发送消息
        logger.debug(f"clint_id: {self.client_id}, status: {rc[0]}, offset: {rc[1]}, published: {rc.is_published()}")

        # 如果发送消息失败则重连重试三次
        if rc[0] == 4:
            re_num = 0
            while re_num < 3:
                re_num += 1
                self.client.reconnect()
                time.sleep(1)
                rc = self.client.publish(topic, payload=data, qos=0)  # 发送消息
                logger.debug(
                    f"clint_id: {self.client_id}, status: {rc[0]}, offset: {rc[1]}, published: {rc.is_published()}")
                if rc[0] == 0 and rc.is_published():
                    break
            else:
                raise MqttSendMessageException("mqtt消息发送失败，请联系管理员")



import os

from .config_json import config_json

__all__ = ["config"]


class Config:
    def __init__(self):
        idc = os.environ.get('IDC')
        if idc:
            self.config = config_json[idc]
        else:
            self.config = config_json["kaifa"]

    def get_log_level_config(self):
        return self.config["log_level"]

    def get_alarm_config(self):
        return self.config["alarm"]


config = Config()



import os
import logging
import threading
import yaml

from .apollo_client import ApolloClient
from .config_group import ConfigGroup
from .configger import Configger
from ..utils.exception_base import ConfigException

__all__ = ["ConfigClient"]

LEGAL_ENV = {"DEV", "PRO"}

logger = logging.getLogger(__name__)

_lock = threading.RLock()


def _acquire_lock():
    if _lock:
        _lock.acquire()


def _release_lock():
    if _lock:
        _lock.release()


class ConfigClient(object):
    """
    Wrapper for pyapollo
    """
    client = None
    configger_dict = {}

    @staticmethod
    def init(lib_app_id: str = None, url: str = None, timeout: int = 120):
        """
        Initialize Apollo client

        :param lib_app_id: str, required for library, optional for app, application identification
        :param url: str, required when "DEV", optional for others, Apollo config service url, default value is None
        :param timeout: int, optional, default value is 120(s)
        """
        if ConfigClient.client is not None:
            return

        # APP's init, looking in environment variables
        if lib_app_id is None:
            app_id = os.environ.get("APP_ID", "NOT_EXIST")
            if app_id is "NOT_EXIST":
                raise ConfigException("environment variable APP_ID is empty")
        # library's init
        else:
            app_id = lib_app_id

        env = os.environ.get("ENV", "")
        if env not in LEGAL_ENV:
            raise ConfigException("invalid environment variable ENV")

        idc = os.environ.get("IDC", "NOT_EXIST")
        if idc is "NOT_EXIST":
            raise ConfigException("environment variable IDC is empty")

        if url is None:
            with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), "config.yaml")) as yaml_file:
                apollo_urls = yaml.safe_load(yaml_file)
                url = apollo_urls.get(env)

        logger.debug("Apollo: {config_server_url}, application: {application}, cluster: {idc}".format(
            config_server_url=url,
            application=app_id,
            idc=idc
        ))
        ConfigClient.client = ApolloClient(app_id=app_id, cluster=idc, config_server_url=url, timeout=timeout)
        ConfigClient.client.start(catch_signals=False)
        return

    @staticmethod
    def get_value(key: str, namespace: str):
        """
        Get value from Apollo by key and namespace

        :param key: str, config key
        :param namespace: str, config namespace
        :return: str, config value
        """
        if ConfigClient.client is None:
            raise ConfigException("ConfigClient has not been initialized")
        return ConfigClient.client.get_value(key, namespace=namespace, auto_fetch_on_cache_miss=True)

    @staticmethod
    def get_group(group: str, namespace: str):
        """
        Get ConfigGroup by prefix and namespace

        :param group: str, config common prefix
        :param namespace: str, config namespace
        :return: ConfigGroup, convenient config getter (reference ConfigGroup defined above)
        """
        if ConfigClient.client is None:
            raise ConfigException("ConfigClient has not been initialized")
        return ConfigGroup(ConfigClient.client, namespace, group)

    @staticmethod
    def get_configger(namespace: str):
        """
        Get Configger by namespace

        :param namespace: str, config namespace
        :return: Configger, wrapped ApolloClient with specific namespace (reference Python's logger)
        """
        if ConfigClient.client is None:
            raise ConfigException("ConfigClient has not been initialized")
        _acquire_lock()
        if namespace in ConfigClient.configger_dict:
            configger = ConfigClient.configger_dict[namespace]
        else:
            configger = Configger(ConfigClient.client, namespace)
            ConfigClient.configger_dict[namespace] = configger
        _release_lock()
        return configger

    @staticmethod
    def register_callback(key: str, namespace: str, callback):
        """
        Register callback function for specific config's change

        :param key: str
        :param namespace: str
        :param callback: function
        """
        if ConfigClient.client is None:
            raise ConfigException("ConfigClient has not been initialized")
        ConfigClient.client.register_callback(key, namespace, callback)



import os
import sys

PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir))
sys.path.append(PATH)


from src.winhye_common.utils import CookieRsa


def test_ras():
    obj = CookieRsa()
    # encrypt = obj.rsa_encrypt('text')
    decrypt = obj.rsa_decrypt("RtM26n+1fZ5DMGwLdZCWEYUkGxfntJdIvKgkvX61Qsq1bsTae+vdat37jL9UttUd1wB9vl42nIf00m2eCnky3LZta6/FL3qIyKR5seI4GHsFtY1HyDX4HQR4QvGy7j27o8M5Ow3yYyrNGZLXctXEb1BlqBvoKMsILlnLDdXEk80=")
    # print(encrypt)
    print(decrypt)


if __name__ == '__main__':
    test_ras()



import os
import sys
import time

# PATH = os.path.join(os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir)), "winhye_common")
PATH2 = os.path.abspath(os.path.join(os.path.dirname(__file__), os.path.pardir))

# sys.path.append(PATH)
sys.path.append(PATH2)
print(PATH2)

from src.winhye_common.winhye_logger import logging as logging


def log_test():
    logger = logging.getLogger()
    for i in range(10000):
        logger.info("1111111111111111")
        logger.debug("222222222222222222")
        time.sleep(1)


def log_test2():
    logger = logging.getLogger()
    logger.report("123456")


def log_test3():
    logger = logging.getLogger()
    logger.error('123')
    import datetime
    print(datetime.datetime.now())


if __name__ == '__main__':
    log_test3()



import logging

from Tea.core import TeaCore

from alibabacloud_sts20150401.client import Client as Sts20150401Client
from alibabacloud_tea_openapi import models as open_api_models
from alibabacloud_sts20150401 import models as sts_20150401_models
from alibabacloud_tea_util.client import Client as UtilClient

from winhye_common.winhye_logger import logging as logging

logger = logging.getLogger()


class OssTemporaryPermissions:
    def __init__(self, endpoint, access_key_id, access_key_secret, role_arn, role_session_name, duration_seconds=3600):
        self.endpoint = endpoint  # 访问的域名
        self.access_key_id = access_key_id
        self.access_key_secret = access_key_secret
        self.role_arn = role_arn  # 角色Arn
        self.role_session_name = role_session_name  # 角色Arn名称
        self.duration_seconds = duration_seconds  # SecurityToken过期时间

    def create_client(self):
        """
        使用AK&SK初始化账号Client
        @param access_key_id:
        @param access_key_secret:
        @return: Client
        @throws Exception
        :param end_point:
        """
        config = open_api_models.Config(
            # 您的AccessKey ID,
            access_key_id=self.access_key_id,
            # 您的AccessKey Secret,
            access_key_secret=self.access_key_secret
        )
        # 访问的域名
        config.endpoint = self.endpoint
        return Sts20150401Client(config)

    def get_security_token(self):
        retry_count = 0
        while True:
            try:
                retry_count += 1
                client = self.create_client()
                assume_role_request = sts_20150401_models.AssumeRoleRequest()
                assume_role_request.duration_seconds = self.duration_seconds
                assume_role_request.role_arn = self.role_arn
                assume_role_request.role_session_name = self.role_session_name
                resp = client.assume_role(assume_role_request)
                return UtilClient.to_jsonstring(TeaCore.to_map(resp))
            except Exception as e:
                if retry_count >= 3:
                    logger.error(e)
                    raise Exception("oss_temporary_permissions has error")


if __name__ == '__main__':
    tok = OssTemporaryPermissions(
        'sts.cn-shenzhen.aliyuncs.com',
        'LTAI5t7p1eu71D42w6rQgRVe',
        'vBwcJofSyQUqm1GCBah5mIfOy8oDzx',
        'acs:ram::1153626070681379:role/ramoss',
        'RamOss',
        3600
    )
    aa = tok.get_security_token()
    print(aa)
    # '''
    #     oss_temporary_permissions.endpoint = sts.cn-shenzhen.aliyuncs.com
    #     oss_temporary_permissions.access_key_id = LTAI5t7p1eu71D42w6rQgRVe
    #     oss_temporary_permissions.access_key_secret = vBwcJofSyQUqm1GCBah5mIfOy8oDzx
    #     oss_temporary_permissions.role_arn = acs:ram::1153626070681379:role/ramoss
    #     oss_temporary_permissions.role_session_name = RamOss
    #     oss_temporary_permissions.bucket_name = winhye-kaifa
    #     oss_temporary_permissions.duration_seconds = 3600
    # '''



from pyapollos import ApolloClient

__all__ = ["ApolloClientInit"]


class ApolloClientInit:

    def __init__(self, app_id, config_server_url, cluster="default"):
        self.app_id = app_id
        self.config_server_url = config_server_url
        self.cluster = cluster
        self.apollo_client = ApolloClient(app_id=self.app_id, cluster=self.cluster,
                                          config_server_url=self.config_server_url)

    def get_config(self, config_key, namespace="application"):
        return self.apollo_client.get_value(config_key, namespace=namespace)
